pub struct Node { /* private fields */ }Expand description
A node in the DAG containing a transaction or consensus message
Examples
use qudag_dag::{Node, NodeState};
// Create a new node with payload and no parents (genesis node)
let payload = b"Hello, DAG!".to_vec();
let node = Node::new(payload.clone(), vec![]);
assert_eq!(node.payload(), &payload);
assert_eq!(node.state(), NodeState::Pending);
assert!(node.parents().is_empty());
// Hash is computed deterministically
let hash = node.hash();
assert_eq!(hash.as_bytes().len(), 32);Implementations
Sourceimpl Node
impl Node
Sourcepub fn new(payload: Vec<u8>, parents: Vec<Hash>) -> Node
pub fn new(payload: Vec<u8>, parents: Vec<Hash>) -> Node
Creates a new node with the given payload and parents
Examples
use qudag_dag::Node;
// Create a genesis node (no parents)
let payload = b"Genesis block".to_vec();
let node = Node::new(payload, vec![]);
// Create a child node
let parent_hash = node.hash();
let child_payload = b"Child block".to_vec();
let child_node = Node::new(child_payload, vec![parent_hash]);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Node
impl<'de> Deserialize<'de> for Node
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Node, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Node, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for Node
impl Serialize for Node
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more